@@ -26,8 +26,9 @@ import sys
 try:
     #from django_tools.utils import info_print;info_print.redirect_stdout()
     import django
-    import dbpreferences
-    import django_tools
+    import dbpreferences # http://code.google.com/p/django-dbpreferences/
+    import django_tools # http://code.google.com/p/django-tools/
+    import django_processinfo # https://github.com/jedie/django-processinfo
     import pylucid_project
     from pylucid_project.system.plugin_setup_info import PyLucidPluginSetupInfo
 except Exception, e:
@@ -35,19 +36,13 @@ except Exception, e:
     sys.stderr.write(traceback.format_exc())
     raise
 
-try:
-    import south
-except ImportError:
-    _south_exists = False
-else:
-    _south_exists = True
+
+# include app settings from ./django_processinfo/app_settings.py
+from django_processinfo import app_settings as PROCESSINFO
 
 
 # Used by a few dynamic settings:
-if "runserver" in sys.argv:
-    RUN_WITH_DEV_SERVER = True
-else:
-    RUN_WITH_DEV_SERVER = False
+RUN_WITH_DEV_SERVER = "runserver" in sys.argv
 
 
 PYLUCID_BASE_PATH = os.path.abspath(os.path.dirname(pylucid_project.__file__))
@@ -94,27 +89,41 @@ SITE_ID = 1 # Can be changed in local_settings
 ROOT_URLCONF = 'pylucid_project.urls'
 
 MIDDLEWARE_CLASSES = (
-    'pylucid_project.middlewares.ip_ban.IPBanMiddleware',
+    # Save process informations. More info: https://github.com/jedie/django-processinfo
+    'django_processinfo.middlewares.django_processinfo.ProcessInfoMiddleware',
 
-    'django_tools.local_sync_cache.LocalSyncCacheMiddleware.LocalSyncCacheMiddleware',
+    # Block banned IP addresses and delete old pylucid.models.BanEntry items:
+    'pylucid_project.middlewares.ip_ban.IPBanMiddleware',
 
     # Insert a statistic line into the generated page:
     'pylucid_project.middlewares.pagestats.PageStatsMiddleware',
 
-    'django.middleware.cache.UpdateCacheMiddleware',
+    # Calls check_state() for every "Local sync cache" to reset out-dated caches
+    'django_tools.local_sync_cache.LocalSyncCacheMiddleware.LocalSyncCacheMiddleware',
 
-    # From http://code.google.com/p/django-tools/
+    # make the request object everywhere available with a thread local storage:
     'django_tools.middlewares.ThreadLocal.ThreadLocalMiddleware',
 
+    # Set SITE_ID dynamically base on the current domain name **Experimental** :
+    # To activate set "USE_DYNAMIC_SITE_MIDDLEWARE = True" in your local_settings.py
+    'django_tools.middlewares.DynamicSite.DynamicSiteMiddleware',
+
     'django.contrib.sessions.middleware.SessionMiddleware',
-    'django.middleware.csrf.CsrfViewMiddleware',
-    'django.middleware.locale.LocaleMiddleware',
-    'django.middleware.common.CommonMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'django.middleware.locale.LocaleMiddleware',
+
+    # Own simple cache implementation similar to https://docs.djangoproject.com/en/1.3/topics/cache/#the-per-site-cache
+    'pylucid_project.middlewares.cache.PyLucidFetchFromCacheMiddleware',
+    'pylucid_project.middlewares.cache.PyLucidUpdateCacheMiddleware',
+
+    'django.middleware.csrf.CsrfViewMiddleware',
+    'django.middleware.common.CommonMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
 
+    # Create request.user_settings at process_request() and save it on process_response():
     'dbpreferences.middleware.DBPreferencesMiddleware',
 
+    # Create request.PYLUCID and log process_exception(): 
     'pylucid_project.middlewares.pylucid_objects.PyLucidMiddleware',
 
     # slow down the django developer server
@@ -122,7 +131,6 @@ MIDDLEWARE_CLASSES = (
 #    'django_tools.middlewares.SlowerDevServer.SlowerDevServerMiddleware',
 
     'django.contrib.redirects.middleware.RedirectFallbackMiddleware',
-    'django.middleware.cache.FetchFromCacheMiddleware',
 
     'django.middleware.transaction.TransactionMiddleware',
     'reversion.middleware.RevisionMiddleware',
@@ -134,7 +142,6 @@ MIDDLEWARE_CLASSES = (
     'pylucid_project.middlewares.message_level.MessageLevelMiddleware',
 )
 
-
 # Add stack information to every messages, but only if..
 #     ...settings.DEBUG == True
 # or
@@ -145,6 +152,7 @@ MESSAGE_STORAGE = "django_tools.utils.messages.StackInfoStorage"
 # initialized all pylucid plugins
 PYLUCID_PLUGIN_SETUP_INFO = PyLucidPluginSetupInfo(
     plugin_package_list=(
+        (PYLUCID_BASE_PATH, "pylucid_project", "apps"), # base apps
         (PYLUCID_BASE_PATH, "pylucid_project", "pylucid_plugins"),
         (PYLUCID_BASE_PATH, "pylucid_project", "external_plugins"),
     ),
@@ -152,19 +160,21 @@ PYLUCID_PLUGIN_SETUP_INFO = PyLucidPluginSetupInfo(
     verbose=False
 )
 
-TEMPLATE_DIRS = (
-    os.path.join(PYLUCID_BASE_PATH, "apps/pylucid/templates/"),
-    os.path.join(PYLUCID_BASE_PATH, "apps/pylucid_admin/templates/"),
-    os.path.join(PYLUCID_BASE_PATH, "apps/pylucid_update/templates/"),
 
+# Add all templates subdirs from all existing PyLucid apps + plugins
+TEMPLATE_DIRS = PYLUCID_PLUGIN_SETUP_INFO.template_dirs
+
+# Append "static" template directories:
+TEMPLATE_DIRS += (
     os.path.join(os.path.abspath(os.path.dirname(django_tools.__file__)), "templates/"),
     os.path.join(os.path.abspath(os.path.dirname(dbpreferences.__file__)), "templates/"),
+    os.path.join(os.path.abspath(os.path.dirname(django_processinfo.__file__)), "templates/"),
+
     os.path.join(os.path.abspath(os.path.dirname(django.__file__)), "contrib/admin/templates"),
 )
-# Add all templates subdirs from all existing PyLucid plugins
-TEMPLATE_DIRS += PYLUCID_PLUGIN_SETUP_INFO.template_dirs
 #print "settings.TEMPLATE_DIRS:\n", "\n".join(TEMPLATE_DIRS)
 
+
 TEMPLATE_LOADERS = (
     'dbtemplates.loader.Loader',
     'django.template.loaders.filesystem.Loader',
@@ -211,21 +221,15 @@ INSTALLED_APPS = (
     'django.contrib.comments',
     'django.contrib.redirects',
 
-    # PyLucid own apps:
-    'pylucid_project.apps.pylucid',
-    'pylucid_project.apps.pylucid_admin',
-    'pylucid_project.apps.pylucid_update', # Only needed for v0.8 users
-
     # external apps shipped and used with PyLucid:
     'dbpreferences',
     'dbtemplates',
     'reversion',
     'tagging',
+    'south',
+    'django_processinfo',
 )
-if _south_exists: # Add south if it can be imported above
-    INSTALLED_APPS += ("south",)
-
-# Add all existing PyLucid plugins
+# Add all existing PyLucid apps + plugins
 INSTALLED_APPS += PYLUCID_PLUGIN_SETUP_INFO.installed_plugins
 #print "settings.INSTALLED_APPS:", "\n".join(INSTALLED_APPS)
 
@@ -235,6 +239,13 @@ COMMENTS_APP = "pylucid_project.pylucid_plugins.pylucid_comments"
 #Default: 'django.test.simple.run_tests'
 TEST_RUNNER = 'pylucid_project.tests.test_tools.test_runner.PyLucidTestRunner'
 
+if RUN_WITH_DEV_SERVER:
+    # print mails to console if dev server used.
+    EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
+    ADMINS = (
+        ("test", "dev_server_test@example_domain.tld"),
+    )
+
 #_____________________________________________________________________________
 # PyLucid own settings
 
@@ -280,6 +291,10 @@ else:
 #     Example-2: "/home/foo/htdocs/media/"
 MEDIA_ROOT = os.path.join(PYLUCID_BASE_PATH, "media") + "/"
 
+# Set base path for include plugin: 
+# http://www.pylucid.org/permalink/381/about-the-include-plugin
+PYLUCID_INCLUDE_BASEPATH = MEDIA_ROOT
+
 # URL that handles the media served from MEDIA_ROOT.
 #     Example-1: "/media/" (default)
 #     Examlpe-2: "http://other_domain.net/media/"
@@ -328,6 +343,12 @@ TIME_ZONE = "UTC"
 # (Default from django is en-us, but this doesn't exist in PyLucid installed data)
 LANGUAGE_CODE = "en"
 
+# https://docs.djangoproject.com/en/1.3/ref/settings/#std:setting-LOCALE_PATHS
+LOCALE_PATHS = (
+    os.path.join(PYLUCID_BASE_PATH, "apps", "pylucid", "locale"),
+)
+USE_I18N = True
+
 #_______________________________________________________________________________
 # dbtemplates settings
 # http://packages.python.org/django-dbtemplates/overview.html#settings
@@ -363,7 +384,9 @@ CACHES = {
         'LOCATION': 'PyLucid-local_sync-cache',
     },
 }
-CACHE_MIDDLEWARE_ANONYMOUS_ONLY = True
+
+# Set default cache timeout (in seconds) to 2 Days (used in own PyLucid cache middleware, too) 
+CACHE_MIDDLEWARE_SECONDS = 60 * 60 * 48
 
 #_______________________________________________________________________________
 
@@ -371,7 +394,9 @@ CACHE_MIDDLEWARE_ANONYMOUS_ONLY = True
 try:
     from local_settings import *
 except ImportError, err:
-    if str(err) == "No module named local_settings":
+    if "create_instance" in sys.argv:
+        pass
+    elif str(err) == "No module named local_settings":
         msg = (
             "There is no local_settings.py file in '%s' !"
             " (Original error was: %s)\n"
